@@ -507,3 +507,8 @@ if (Froxlor::isFroxlorVersion('2.0.21')) {
 	Update::showUpdateStep("Updating from 2.0.21 to 2.0.22", false);
 	Froxlor::updateToVersion('2.0.22');
 }
+
+if (Froxlor::isFroxlorVersion('2.0.22')) {
+	Update::showUpdateStep("Updating from 2.0.22 to 2.0.23", false);
+	Froxlor::updateToVersion('2.0.23');
+}
